import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * An Actor that listens to two analog sticks. One stick is for horizontal movement,
 * the other is for vertical movement. The movement of these axis alter the location
 * of this actor.
 * 
 * @author Joseph Lenton
 */
public class ControllerAnalog  extends ControllerActor
{
    private static final int MAX_MOVE = 24;
    
    private final GamePad.Axis axis;
    private int startX, startY;
    
    /**
     * @param controller The GamePad to listen from.
     * @param xAxis The horizontal movement to listen too.
     * @param yAxis The vertical movement to listen too.
     */
    public ControllerAnalog(GamePad controller, GamePad.Axis axis )
    {
        super( controller );
        
        this.axis = axis;
    }
    
    /**
     * Records it's starting location.
     * @param world The world this was added too, ignored.
     */
    public void addedToWorld(World world)
    {
        startX = getX();
        startY = getY();
    }
    
    /**
     * If the analog stick is being moved, then it will move this actor around it's
     * starting location.
     */
    public void act() 
    {
        final Direction direction = getGamePad().getAxis( axis );
        
        final double angle = Math.toRadians( direction.getAngle() );
        final double dist = MAX_MOVE*direction.getStrength();
        
        final int x = (int) ( dist*Math.cos(angle) );
        final int y = (int) ( dist*Math.sin(angle) );
        
        setLocation( startX+x, startY+y );
    }
}
