import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * This is for listening to a GamPad button and then alters it's
 * image accordingly.
 * 
 * @author Joseph Lenton
 */
public class ControllerButton  extends ControllerActor
{
    private final GreenfootImage normal;
    private final GreenfootImage highlight;
    private final GamePad.Button button;
    
    /**
     * Creates a new button on the controller. The parameters tell it which button it is
     * listening too, it's normal non pressed image and the image to show when that button is pressed.
     * @param controller The GamePad this is listening too.
     * @param button The index of the button to listen to.
     * @param normal The image to display when the button is not pressed.
     * @param highlight The image to display when the button is pressed.
     */
    public ControllerButton(GamePad controller, GamePad.Button button, GreenfootImage normal, GreenfootImage highlight)
    {
        super( controller );
        
        this.button = button;
        this.normal = normal;
        this.highlight = highlight;
        
        setImage( normal );
    }
    
    /**
     * If this actors button is down, then it will look highlighted.
     * If it is up then it will look normal.
     */
    public void act() 
    {
        if ( getGamePad().isDown(button) ) {
            setImage( highlight );
        } else {
            setImage( normal );
        }
    }    
}
